CaptimReloadHighReg

Type Alias CaptimReloadHighReg 

pub type CaptimReloadHighReg = RegValueT<CaptimReloadHighReg_SPEC>;
Capture Timer reload high value and Delay in shot mode

Aliased Type

pub struct CaptimReloadHighReg { /* private fields */ }

Implementations

Source

impl CaptimReloadHighReg

pub fn captim_reload_high( self, ) -> RegisterField<0, 0xffff, 1, 0, u16, u16, CaptimReloadHighReg_SPEC, RW>

Reload high value or max high value in timer mode, Delay phase duration in oneshot mode. Actual delay is the register value plus synchronization time (3 clock cycles)